django-guardian - per object permissions for Django — django-guardian v1.0.0.beta1 documentation

### Navigation

- index
- modules |
- next |
- django-guardian v1.0.0.beta1 documentation »

# django-guardian - per object permissions for Django

Date: | January 10, 2011

Documentation:

- Overview
  - Features
  - Incoming
  - Source and issue tracker
  - Alternate projects
- Installation
- Configuration
- User Guide
  - Assign object permissions
  - Check object permissions
  - Remove object permissions
  - Admin integration
  - Caveats
- API Reference
  - Admin
  - Backends
  - Core
  - Decorators
  - Forms
  - Management commands
  - Managers
  - Models
  - Shortcuts
  - Utilities
  - Template tags
- Development
  - Example project
  - Testing
  - Changelog

## Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- django-guardian v1.0.0.beta1 documentation »